@@ -1,8 +1,10 @@
-__version__ = "0.7.0"
+__version__ = "0.9.0"
 
 from balladeer.drama import Drama
+from balladeer.gesture import Gesture
+from balladeer.gesture import Hand
+from balladeer.gesture import Head
 from balladeer.speech import Article
-from balladeer.speech import Gesture
 from balladeer.speech import Name
 from balladeer.speech import Phrase
 from balladeer.speech import Pronoun
